@@ -629,6 +629,8 @@ class AWSThing:
             f"brand: {self.brand}\n"
             f"model: {self.model}\n"
             f"type: {self.type}\n"
+            f"firmware_code: {self.firmware_code}\n"
+            f"firmawre_version: {self.firmware_version}\n"
             f"available: {self.available}\n"
             f"status_code: {self.status_code}\n"
             f"support_code: {self.support_code}\n"
@@ -703,6 +705,30 @@ class AWSThing:
         """
         
         return getattr(self._support_code, "Brand")
+    
+    @property
+    def firmware_version(self) -> str:
+        """Firmware version.
+        
+        Returns
+        -------
+        str
+            Device firmware version.
+        """
+
+        return getattr(self._support_code, "FirmwareVersion")
+    
+    @property
+    def firmware_code(self) -> str:
+        """Firmware code.
+
+        Returns
+        -------
+        str
+            Device firmware code.
+        """
+
+        return getattr(self._support_code, "FirmwareCode")
 
     @property
     def gateway_mac_address(self) -> str:
@@ -1100,37 +1126,37 @@ class JciHitachiAWSAPI:
             If an error occurs, RuntimeError will be raised.
         """
 
-        self._check_before_publish()
-
         for name, thing in self._things.items():
             if (device_name and name != device_name) or thing.type == "unknown":
                 continue
 
+            self._check_before_publish()
+
             if refresh_support_code:
                 self._mqtt.publish(f"{self._host_identity_id}/{thing.thing_name}/registration/request", {"Timestamp": time.time()})
                 if not self._mqtt.mqtt_events.device_support_event.wait(timeout=10.0):
                     raise RuntimeError(f"An error occurred when refreshing {name} support code.")
+                if thing.thing_name not in self._mqtt.mqtt_events.device_support:
+                    raise RuntimeError(f"An event occurred but wasn't accompanied with data when refreshing {name} support code.")
                 
-                thing.support_code = self._mqtt.mqtt_events.device_support.get(thing.thing_name)
-                
-                self._mqtt.mqtt_events.device_support_event.clear()
+                thing.support_code = self._mqtt.mqtt_events.device_support[thing.thing_name]
 
             if refresh_shadow:
                 self._mqtt.publish_shadow(thing.thing_name, "get", shadow_name="info")
                 if not self._mqtt.mqtt_events.device_shadow_event.wait(timeout=10.0):
                     raise RuntimeError(f"An error occurred when refreshing {name} shadow.")
+                if thing.thing_name not in self._mqtt.mqtt_events.device_shadow:
+                    raise RuntimeError(f"An event occurred but wasn't accompanied with data when refreshing {name} shadow.")
 
-                thing.shadow = self._mqtt.mqtt_events.device_shadow.get(thing.thing_name)
-
-                self._mqtt.mqtt_events.device_shadow_event.clear()
+                thing.shadow = self._mqtt.mqtt_events.device_shadow[thing.thing_name]
 
             self._mqtt.publish(f"{self._host_identity_id}/{thing.thing_name}/status/request", {"Timestamp": time.time()})
             if not self._mqtt.mqtt_events.device_status_event.wait(timeout=10.0):
                 raise RuntimeError(f"An error occurred when refreshing {name} status code.")
+            if thing.thing_name not in self._mqtt.mqtt_events.device_status:
+                raise RuntimeError(f"An event occurred but wasn't accompanied with data when refreshing {name} status code.")
             
-            thing.status_code = self._mqtt.mqtt_events.device_status.get(thing.thing_name)
-            
-            self._mqtt.mqtt_events.device_status_event.clear()
+            thing.status_code = self._mqtt.mqtt_events.device_status[thing.thing_name]
 
     def get_status(self, device_name: Optional[str] = None, legacy: bool = False) -> Dict[str, JciHitachiAWSStatus]:
         """Get device status after refreshing status.
@@ -1158,6 +1184,15 @@ class JciHitachiAWSAPI:
                 statuses[name] = thing.status_code.legacy_status
             else:
                 statuses[name] = thing.status_code
+
+            # here we inject temp and humidity limitations from the support code
+            if thing.type == "AC":
+                statuses[name]._status["max_temp"] = thing.support_code.max_temp
+                statuses[name]._status["min_temp"] = thing.support_code.min_temp
+            elif thing.type == "DH":
+                statuses[name]._status["max_humidity"] = thing.support_code.max_humidity
+                statuses[name]._status["min_humidity"] = thing.support_code.min_humidity
+
         return statuses
 
     def set_status(self, status_name: str, device_name: str, status_value: int = None, status_str_value: str = None) -> bool:
@@ -1195,6 +1230,7 @@ class JciHitachiAWSAPI:
             status_name = status_name,
             status_value = status_value,
             status_str_value = status_str_value,
+            support_code = thing.support_code,
         )
 
         if not is_valid:
